==> ngx-forkable-http-client-0.0.1.tgz: package/bundles/ngx-forkable-http-client.es5.js <==
import { Inject, Injectable, NgModule, Optional } from '@angular/core';
import { HTTP_INTERCEPTORS, HttpBackend, HttpClient, HttpClientModule } from '@angular/common/http';
import { __extends } from 'tslib';
import * as tslib_1 from 'tslib';

function createInterceptorHandler(baseHandler, interceptors) {
    return interceptors.reduceRight(function (next, interceptor) { return new HttpInterceptorHandler(next, interceptor); }, baseHandler);
}
var HttpInterceptorHandler = (function () {
    function HttpInterceptorHandler(next, interceptor) {
        this.next = next;
        this.interceptor = interceptor;
    }
    HttpInterceptorHandler.prototype.handle = function (request) {
        return this.interceptor.intercept(request, this.next);
    };
    return HttpInterceptorHandler;
}());

var ForkableHttpClient = (function (_super) {
    __extends(ForkableHttpClient, _super);
    function ForkableHttpClient(backend, interceptors) {
        var _this = _super.call(this, createInterceptorHandler(backend, interceptors || [])) || this;
        _this.backend = backend;
        _this.interceptors = interceptors;
        return _this;
    }
    ForkableHttpClient.prototype.fork = function () {
        var interceptors = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            interceptors[_i] = arguments[_i];
        }
        return new ForkableHttpClient(this.backend, this.interceptors.concat(interceptors));
    };
    return ForkableHttpClient;
}(HttpClient));
ForkableHttpClient.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ForkableHttpClient.ctorParameters = function () { return [
    { type: HttpBackend, },
    { type: Array, decorators: [{ type: Optional }, { type: Inject, args: [HTTP_INTERCEPTORS,] },] },
]; };
function forkHttpClient(parent) {
    var interceptors = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        interceptors[_i - 1] = arguments[_i];
    }
    return parent.fork.apply(parent, interceptors);
}

var ForkableHttpClientModule = (function () {
    function ForkableHttpClientModule() {
    }
    return ForkableHttpClientModule;
}());
ForkableHttpClientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    HttpClientModule
                ],
                providers: [
                    ForkableHttpClient
                ]
            },] },
];
/** @nocollapse */
ForkableHttpClientModule.ctorParameters = function () { return []; };

export { ForkableHttpClientModule, ForkableHttpClient, forkHttpClient, createInterceptorHandler, HttpInterceptorHandler };

==> ngx-forkable-http-client-0.1.0.tgz: package/bundles/ngx-forkable-http-client.es5.js <==
import { Inject, Injectable, NgModule, Optional } from '@angular/core';
import { HTTP_INTERCEPTORS, HttpBackend, HttpClient, HttpClientModule, HttpHandler } from '@angular/common/http';
import { __extends } from 'tslib';
import * as tslib_1 from 'tslib';

function createInterceptorHandler(baseHandler, interceptors) {
    return interceptors.reduceRight(function (next, interceptor) { return new HttpInterceptorHandler(next, interceptor); }, baseHandler);
}
var HttpInterceptorHandler = (function () {
    function HttpInterceptorHandler(next, interceptor) {
        this.next = next;
        this.interceptor = interceptor;
    }
    HttpInterceptorHandler.prototype.handle = function (request) {
        return this.interceptor.intercept(request, this.next);
    };
    return HttpInterceptorHandler;
}());

var ForkableHttpClient = (function (_super) {
    __extends(ForkableHttpClient, _super);
    function ForkableHttpClient(baseHandler, interceptors) {
        var _this = _super.call(this, createInterceptorHandler(baseHandler, interceptors || [])) || this;
        _this.baseHandler = baseHandler;
        _this.interceptors = interceptors;
        return _this;
    }
    ForkableHttpClient.prototype.fork = function () {
        var interceptors = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            interceptors[_i] = arguments[_i];
        }
        return new ForkableHttpClient(this.baseHandler, this.interceptors.concat(interceptors));
    };
    return ForkableHttpClient;
}(HttpClient));
ForkableHttpClient.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ForkableHttpClient.ctorParameters = function () { return [
    { type: HttpHandler, decorators: [{ type: Inject, args: [HttpBackend,] },] },
    { type: Array, decorators: [{ type: Optional }, { type: Inject, args: [HTTP_INTERCEPTORS,] },] },
]; };
function forkHttpClient(parent) {
    var interceptors = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        interceptors[_i - 1] = arguments[_i];
    }
    return parent.fork.apply(parent, interceptors);
}

var ForkableHttpClientModule = (function () {
    function ForkableHttpClientModule() {
    }
    return ForkableHttpClientModule;
}());
ForkableHttpClientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    HttpClientModule
                ],
                providers: [
                    ForkableHttpClient
                ]
            },] },
];
/** @nocollapse */
ForkableHttpClientModule.ctorParameters = function () { return []; };

export { ForkableHttpClientModule, ForkableHttpClient, forkHttpClient, createInterceptorHandler, HttpInterceptorHandler };
